From: Sarvjeet Date: Fri, 20 Mar 2015 10:12:37 +0000 (+0530) Subject: Give user 48ms to read each character of a PAM message, earlier it was 16ms X-Git-Tag: archive/raspbian/50.5-1+rpi1~1^2~1013^2^2~1421 X-Git-Url: https://dgit.raspbian.org/%22http://www.example.com/cgi/%22/%22http:/www.example.com/cgi/%22?a=commitdiff_plain;h=88973857146f91acd3b633234afa2c2bb358392a;p=gnome-shell.git Give user 48ms to read each character of a PAM message, earlier it was 16ms User read time per character has been changed from 16ms to 48ms because the message of information about last login is displayed for half a sec that is not a good user experience. So time to read a character is increased to 48ms from 16ms. https://bugzilla.gnome.org/show_bug.cgi?id=720885 --- diff --git a/js/gdm/util.js b/js/gdm/util.js index 6286b84fc..2ff59cb75 100644 --- a/js/gdm/util.js +++ b/js/gdm/util.js @@ -35,8 +35,8 @@ const ALLOWED_FAILURES_KEY = 'allowed-failures'; const LOGO_KEY = 'logo'; const DISABLE_USER_LIST_KEY = 'disable-user-list'; -// Give user 16ms to read each character of a PAM message -const USER_READ_TIME = 16 +// Give user 48ms to read each character of a PAM message +const USER_READ_TIME = 48 const MessageType = { NONE: 0,